@@ -40,7 +40,7 @@ getGRanges <- function(df, keep.extra.columns = TRUE, seqinfo = NULL) {
   if (!isTRUEorFALSE(keep.extra.columns))
     stop("'keep.extra.columns' must be TRUE or FALSE")
   if (!all(c("seqnames", "start", "strand") %in% colnames(df)))
-    stop("df must at minimum have 3 columns named: seqnames, start, strand")
+    stop("df must at minimum have 4 columns named: seqnames, start, width and strand")
   if (!is(df, "data.table")) setDT(df)
 
   widths <- if ("width" %in% colnames(df)) {
@@ -140,7 +140,7 @@ getGAlignments <- function(df, seqinfo = NULL) {
       names(mcols) <- names(df)[5]
     }
   }
-  if (!is(df$strand, "factor") | identical(levels(df$strand), c("+", "-", "*"))){
+  if (!is(df$strand, "factor") && identical(levels(df$strand), c("+", "-", "*"))){
     df[, strand := factor(strand, levels = c("+", "-", "*"))]
   }
 
@@ -161,8 +161,8 @@ getGAlignments <- function(df, seqinfo = NULL) {
 #' @keywords internal
 getGAlignmentsPairs <- function(df, strandMode = 0, seqinfo = NULL) {
   if (nrow(df) == 0) {
-    return(GenomicAlignments::GAlignmentPairs(first = GAlignments(seqinfo = seqinfo),
-                                              last = GAlignments(seqinfo = seqinfo),
+    return(GenomicAlignments::GAlignmentPairs(first = GAlignments(),
+                                              last = GAlignments(),
                                               strandMode = strandMode))
   }
   if (is.null(levels(df$seqnames))) {
@@ -173,12 +173,6 @@ getGAlignmentsPairs <- function(df, strandMode = 0, seqinfo = NULL) {
   } else seqinfo <- Seqinfo(levels(df$seqnames))
   names <- df$NAMES
   if (!is.null(df$NAMES)) df$NAMES <- NULL
-
-  isProperPair <- df$isProperPair
-  if (!is.null(df$isProperPair)) {
-    df$isProperPair <- NULL
-  } else isProperPair <- rep(TRUE, nrow(df))
-
   if (ncol(df) == 6){
     mcols <- NULL
   } else {
@@ -205,7 +199,7 @@ getGAlignmentsPairs <- function(df, strandMode = 0, seqinfo = NULL) {
              cigar = as.character(df$cigar2), strand = Rle(factor(strand2, levels)),
              seqinfo = seqinfo, check = FALSE,
              elementMetadata = DataFrame(data.frame(matrix(nrow = nrow(df), ncol = 0)))),
-       isProperPair = isProperPair, strandMode = as.integer(strandMode),
+       isProperPair = rep(TRUE, nrow(df)), strandMode = as.integer(strandMode),
        elementMetadata = mcols, check = FALSE)
 }
 
@@ -415,9 +409,9 @@ combn.pairs <- function(x) {
 #' Read RDS or QS format file
 #'
 #' @param file path to file with "rds" or "qs" file extension
-#' @param nthread numeric, number of threads for qs2::qs_read
+#' @param nthread numeric, number of threads for qs::qread
 #' @return R object loaded from file
-#' @importFrom qs2 qs_read
+#' @importFrom qs qread
 #' @export
 #' @examples
 #' df <- ORFik::ORFik.template.experiment()
@@ -428,16 +422,16 @@ read_RDSQS <- function(file, nthread = 5) {
   stopifnot(format %in% c("qs", "rds", "covqs", "covrds"))
   if (format %in% c("rds", "covrds")) {
     readRDS(file)
-  } else qs2::qs_read(file, nthread = nthread)
+  } else qs::qread(file, nthread = nthread)
 }
 
 #' Read RDS or QS format file
 #'
 #' @param object the object to save
 #' @param file path to file with "rds" or "qs" file extension
-#' @param nthread numeric, number of threads for qs2::qs_save
+#' @param nthread numeric, number of threads for qs::qread
 #' @return R object loaded from file
-#' @importFrom qs2 qs_save
+#' @importFrom qs qread
 #' @export
 #' @examples
 #' path <- tempfile(fileext = ".qs")
@@ -455,7 +449,7 @@ save_RDSQS <- function(object, file, nthread = 5) {
   stopifnot(format %in% c("qs", "rds", "covqs", "covrds"))
   if (format %in% c("rds", "covrds")) {
     saveRDS(object, file)
-  } else qs2::qs_save(object, file, nthread = nthread)
+  } else qs::qsave(object, file, nthread = nthread)
 }
 
 #' A fast ftp directory check
